@@ -2,6 +2,9 @@
 #include "pyobjc-api.h"
 
 #import <CoreServices/CoreServices.h>
+#if PyObjC_BUILD_RELEASE > 1008
+#import <CFNetwork/CFNetwork.h>
+#endif
 
 static const void* 
 mod_retain(const void* info) 
@@ -98,7 +101,7 @@ m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo, const CFStreamEr
 #ifdef __LP64__
 	PyObject* py_error = PyObjC_ObjCToPython("{_CFStreamError=qi}", (void*)error);
 #else
-	PyObject* py_error = PyObjC_ObjCToPython("{_CFStreamError=ii}", (void*)error);
+	PyObject* py_error = PyObjC_ObjCToPython("{_CFStreamError=ll}", (void*)error);
 #endif
 	if (py_error == NULL) {
 		Py_DECREF(py_host);
@@ -121,6 +124,7 @@ m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo, const CFStreamEr
 
 
 #if PyObjC_BUILD_RELEASE >= 1005
+  /* This function is available on 10.5 or later, but the prototype isn't in the headers on 10.5 */
 static PyObject*
 m_CFNetworkExecuteProxyAutoConfigurationScript(PyObject* mod __attribute__((__unused__)),
 		PyObject* args)
@@ -178,7 +182,9 @@ m_CFNetworkExecuteProxyAutoConfigurationScript(PyObject* mod __attribute__((__un
 
 	return rv;
 }
+#endif
 
+#if PyObjC_BUILD_RELEASE >= 1005
 static PyObject*
 m_CFNetworkExecuteProxyAutoConfigurationURL(PyObject* mod __attribute__((__unused__)),
 		PyObject* args)
@@ -311,6 +317,8 @@ static PyMethodDef mod_methods[] = {
 		METH_VARARGS,
 		NULL
 	},
+#endif /* OSX >= 10.5 */
+#if PyObjC_BUILD_RELEASE >= 1005
 	{
 		"CFNetworkExecuteProxyAutoConfigurationURL",
 		(PyCFunction)m_CFNetworkExecuteProxyAutoConfigurationURL,
@@ -342,12 +350,14 @@ PyObjC_MODULE_INIT(_manual)
 		PyObjC_INITERROR();
 	}
 
-#if PyObjC_BUILD_RELEASE >= 1005
+#if PyObjC_BUILD_RELEASE >= 1006
 	if (CFNetworkExecuteProxyAutoConfigurationScript == NULL) {
 		if (PyDict_DelItemString(m, "CFNetworkExecuteProxyAutoConfigurationScript") < 0) {
 			PyObjC_INITERROR();
 		}
 	}
+#endif
+#if PyObjC_BUILD_RELEASE >= 1005
 	if (CFNetworkExecuteProxyAutoConfigurationURL == NULL) {
 		if (PyDict_DelItemString(m, "CFNetworkExecuteProxyAutoConfigurationURL") < 0) {
 			PyObjC_INITERROR();
